<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>Window</name>
    <message>
        <location filename="../Window.js" line="+108"/>
        <source>&amp;Window</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
&amp;Janela
&amp;Janela de Desseleção</translatorcomment>
        <translation>&amp;Janela</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Window Tools</source>
        <translation>Ferramentas janelas</translation>
    </message>
</context>
</TS>
